==> mule-artifact-ast-serialization-1.1.0-20220922-sources.jar: org/mule/runtime/ast/internal/serialization/json/gson/ComponentLocationJsonDeserializer.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.ast.internal.serialization.json.gson;

import static java.net.URI.create;
import static java.util.Collections.emptyList;
import static java.util.Optional.empty;
import static java.util.Optional.of;
import static java.util.Optional.ofNullable;
import static org.mule.runtime.api.component.TypedComponentIdentifier.builder;
import static org.mule.runtime.api.component.TypedComponentIdentifier.ComponentType.valueOf;

import org.mule.runtime.api.component.ComponentIdentifier;
import org.mule.runtime.api.component.TypedComponentIdentifier;
import org.mule.runtime.api.component.location.ComponentLocation;
import org.mule.runtime.dsl.api.component.config.DefaultComponentLocation;
import org.mule.runtime.dsl.api.component.config.DefaultComponentLocation.DefaultLocationPart;

import java.lang.reflect.Type;
import java.net.URI;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import java.util.OptionalInt;

import com.google.gson.JsonArray;
import com.google.gson.JsonDeserializationContext;
import com.google.gson.JsonDeserializer;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonParseException;

/**
 * This class implements a Gson {@link JsonDeserializer} and it can be registered to Gson as a Type Adapter in order to
 * deserialize {@link ComponentLocation}s
 */
public class ComponentLocationJsonDeserializer implements JsonDeserializer<ComponentLocation> {

  @Override
  public ComponentLocation deserialize(JsonElement jsonElement, Type type, JsonDeserializationContext jsonDeserializationContext)
      throws JsonParseException {
    ComponentIdentifierJsonDeserializer componentIdentifierJsonDeserializer = new ComponentIdentifierJsonDeserializer();
    JsonObject locationJsonObject = jsonElement.getAsJsonObject();

    JsonElement nameJsonElement = locationJsonObject.get("name");

    Optional<String> name = nameJsonElement != null ? of(nameJsonElement.getAsString()) : empty();

    JsonArray jsonArray = locationJsonObject.get("parts").getAsJsonArray();

    List<DefaultLocationPart> parts = new ArrayList<>();

    for (JsonElement element : jsonArray) {
      Optional<TypedComponentIdentifier> partIdentifier = empty();

      JsonObject locationPartJsonObject = element.getAsJsonObject();

      JsonElement partPathJsonElement = locationPartJsonObject.get("partPath");
      String partPath = partPathJsonElement != null ? partPathJsonElement.getAsString() : null;

      JsonElement partIdentifierJsonElement = locationPartJsonObject.get("partIdentifier");
      if (partIdentifierJsonElement != null) {
        JsonObject locationPartIdentifierJsonObject = partIdentifierJsonElement.getAsJsonObject();
        JsonElement identifier = locationPartIdentifierJsonObject.get("identifier");
        JsonElement componentType = locationPartIdentifierJsonObject.get("type");

        partIdentifier = ofNullable(identifier != null
            ? builder()
                .identifier(componentIdentifierJsonDeserializer.deserialize(identifier, ComponentIdentifier.class,
                                                                            jsonDeserializationContext))
                .type(valueOf(componentType.getAsJsonObject().get("name").getAsString()))
                .build()
            : null);
      }

      Optional<String> fileName =
          ofNullable(locationPartJsonObject.get("fileName") != null ? locationPartJsonObject.get("fileName").getAsString()
              : null);

      OptionalInt lineInFile = OptionalInt.empty();
      JsonElement lineInFileJsonElement = locationPartJsonObject.get("line");
      if (lineInFileJsonElement != null) {
        lineInFile = OptionalInt.of(lineInFileJsonElement.getAsInt());
      }

      OptionalInt startColumn = OptionalInt.empty();
      JsonElement startColumnJsonElement = locationPartJsonObject.get("column");
      if (startColumnJsonElement != null) {
        startColumn = OptionalInt.of(startColumnJsonElement.getAsInt());
      }

      parts.add(new DefaultLocationPart(partPath, partIdentifier, fileName, lineInFile, startColumn));
    }

    List<URI> importChain;

    if (locationJsonObject.get("importChain") != null) {
      importChain = new ArrayList<>();
      for (JsonElement importChainItem : locationJsonObject.get("importChain").getAsJsonArray()) {
        importChain.add(create(importChainItem.getAsString()));
      }
    } else {
      importChain = emptyList();
    }

    return new DefaultComponentLocation(name, parts, importChain);
  }
}

==> mule-artifact-ast-serialization-1.4.10-20251105.140705-6-sources.jar: org/mule/runtime/ast/internal/serialization/json/gson/ComponentLocationJsonDeserializer.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.ast.internal.serialization.json.gson;

import static java.net.URI.create;
import static java.util.Collections.emptyList;
import static java.util.Optional.empty;
import static java.util.Optional.of;
import static java.util.Optional.ofNullable;

import org.mule.runtime.api.component.TypedComponentIdentifier;
import org.mule.runtime.api.component.location.ComponentLocation;
import org.mule.runtime.dsl.api.component.config.DefaultComponentLocation;
import org.mule.runtime.dsl.api.component.config.DefaultComponentLocation.DefaultLocationPart;

import java.lang.reflect.Type;
import java.net.URI;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import java.util.OptionalInt;

import com.google.gson.JsonArray;
import com.google.gson.JsonDeserializationContext;
import com.google.gson.JsonDeserializer;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonParseException;

/**
 * This class implements a Gson {@link JsonDeserializer} and it can be registered to Gson as a Type Adapter in order to
 * deserialize {@link ComponentLocation}s
 */
public class ComponentLocationJsonDeserializer implements JsonDeserializer<ComponentLocation> {

  @Override
  public ComponentLocation deserialize(JsonElement jsonElement, Type type, JsonDeserializationContext jsonDeserializationContext)
      throws JsonParseException {
    TypedComponentIdentifierJsonDeserializer componentIdentifierJsonDeserializer = new TypedComponentIdentifierJsonDeserializer();
    JsonObject locationJsonObject = jsonElement.getAsJsonObject();

    JsonElement nameJsonElement = locationJsonObject.get("name");

    Optional<String> name = nameJsonElement != null ? of(nameJsonElement.getAsString()) : empty();

    JsonArray jsonArray = locationJsonObject.get("parts").getAsJsonArray();

    List<DefaultLocationPart> parts = new ArrayList<>();

    for (JsonElement element : jsonArray) {
      JsonObject locationPartJsonObject = element.getAsJsonObject();

      JsonElement partPathJsonElement = locationPartJsonObject.get("partPath");
      String partPath = partPathJsonElement != null ? partPathJsonElement.getAsString() : null;

      Optional<TypedComponentIdentifier> partIdentifier =
          ofNullable(componentIdentifierJsonDeserializer.deserialize(locationPartJsonObject.get("partIdentifier"),
                                                                     TypedComponentIdentifier.class,
                                                                     jsonDeserializationContext));

      Optional<String> fileName =
          ofNullable(locationPartJsonObject.get("fileName") != null ? locationPartJsonObject.get("fileName").getAsString()
              : null);

      OptionalInt lineInFile = OptionalInt.empty();
      JsonElement lineInFileJsonElement = locationPartJsonObject.get("line");
      if (lineInFileJsonElement != null) {
        lineInFile = OptionalInt.of(lineInFileJsonElement.getAsInt());
      }

      OptionalInt startColumn = OptionalInt.empty();
      JsonElement startColumnJsonElement = locationPartJsonObject.get("column");
      if (startColumnJsonElement != null) {
        startColumn = OptionalInt.of(startColumnJsonElement.getAsInt());
      }

      parts.add(new DefaultLocationPart(partPath, partIdentifier, fileName, lineInFile, startColumn));
    }

    List<URI> importChain;

    if (locationJsonObject.get("importChain") != null) {
      importChain = new ArrayList<>();
      for (JsonElement importChainItem : locationJsonObject.get("importChain").getAsJsonArray()) {
        importChain.add(create(importChainItem.getAsString()));
      }
    } else {
      importChain = emptyList();
    }

    return new DefaultComponentLocation(name, parts, importChain);
  }
}
